"""Unit testing a module function."""
from lifespline_utils.example import example
from conftest import test_cases, arg_example

def test_example(test_cases):
    """All the test cases will pass."""
    res = True

    for test_case in test_cases:
        inp = test_case[0]
        exp_out = test_case[1]
        res = res and (example(inp) == exp_out)

    assert res

def test_arg_example(arg_example):
    assert arg_example


"""Lifespline Utils Package Setup.
"""
from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


def _increment_version():
    """Increment project version.

    TODO: increment protocol

    Returns:
        str: [description]
    """
    return '0.0.7'


def _get_install_reqs():
    """Get dependencies for the lifespline-utils python package.

    TODO: add to setup(install_requires=_get_install_reqs())

    Returns:
        [str]: A list of dependencies for this package
    """
    # TODO: lifespline_utils.config.Config
    with open("requirements/main.md", mode="r", encoding="UTF-8") as deps:
        return list(deps)


setup(
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "",
        "Operating System :: OS Independent",
    ],
    # pip info
    name="lifespline-utils",
    version=_increment_version(),
    author="diogo",
    author_email="lifespline@fastmail.com",
    description="Lifespline Utils",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lifespline/lifespline-utils",
    # import info
    package_dir={"": "src"},
    packages=["lifespline_utils"],
)
